import os
import chardet


def to_text(text_or_file: str):
    if os.path.exists(text_or_file) and os.path.isfile(text_or_file):
        # 自动检测文件编码
        with open(text_or_file, "rb") as f:
            raw_data = f.read()
            result = chardet.detect(raw_data)
            encoding = result["encoding"]

        # 读取文件内容
        with open(text_or_file, "r", encoding=encoding) as f:
            input_text = f.read()
    else:
        input_text = text_or_file  # 直接使用传入的文本
    return input_text



from langchain_core.messages import HumanMessage, AIMessage
import threading
import json
from .agent import INPUT_MESSAGE, output, CHAT_DATA, clear_chat_data
from .agent_chat import agent_chat
import asyncio


def chat(bot_setting_file: str):
    history = []
    while True:
        input_text = input()
        if not input_text.startswith(INPUT_MESSAGE):
            raise ValueError("Invalid message")
        message = json.loads(input_text[len(INPUT_MESSAGE) :])
        history.append(HumanMessage(message["content"]))
        result = asyncio.run(agent_chat(bot_setting_file, history))
        output("assistant", result)
        history.append(AIMessage(result))


def get_chat_response(bot_setting_file: str, input_text: str):
    result = asyncio.run(agent_chat(bot_setting_file, [HumanMessage(input_text)]))
    return result
